﻿--[[Compute current and new values of Mana Regeneration
	Returns
		manaRegenNormal
		manaRegenCasting
		manaRegenNormalNew
		manaRegenCastingNew
		percentRegen
--]]
local function getCurrentAndNewManaRegen_Depricated(itemIntDelta, itemSpiDelta, itemCastingRegenDelta, itemManaDelta)
	-- Base stats  
	local _, intellect, _, _ = UnitStat("player", 4);
	local _, spirit, _, _ = UnitStat("player", 5);

	local spiritRegen = StatLogic:GetNormalManaRegenFromSpi(spirit + itemSpiDelta, intellect + itemIntDelta);
	
	--Mana regeneration from Spirit while in combat increased by xxx percent 
	--	e.g. Paladin Holy specialization Meditation "Allows 50% of your mana regeneration from Spirit to continue while in combat"
	local percentRegen = StatLogic:GetNormalManaRegenFromSpi(spirit, intellect);
	
		local castingRegen = HealPointsUtil:GetBaseCombatManaRegen() --base combat regen amount that everyone always gets
			+ itemCastingRegenDelta; --items can no longer have casting regen (removed from game). But i can leave param here
  
	local manaRegenNormal = castingRegen + spiritRegen;
	local manaRegenCasting = castingRegen + percentRegen*spiritRegen;
  
	-- Calculator bonuses
	local calcInt = _G["HealPointsVariables1InputBox"]:GetNumber() * (1 + BonusPercentInt);
	local calcSpi = _G["HealPointsVariables2InputBox"]:GetNumber() * (1 + BonusPercentSpi);
	local calcMana = _G["HealPointsVariables3InputBox"]:GetNumber();
	local calcCastingRegen = _G["HealPointsVariables4InputBox"]:GetNumber();
	local calcNormalRegen = _G["HealPointsVariables5InputBox"]:GetNumber();
	local calcPercentRegen = _G["HealPointsVariables6InputBox"]:GetNumber() / 100;

	local spiritRegenNew = StatLogic:GetNormalManaRegenFromSpi(spirit + itemSpiDelta + calcSpi, intellect + itemIntDelta + calcInt);
	
	local manaRegenNormalNew = castingRegen + spiritRegenNew;
	local manaRegenCastingNew = castingRegen + percentRegen*spiritRegenNew;

	if (_G["HealPointsOptionsConfigReplenish"]:GetChecked() == 1) then -- add replenishment
		local currentMana = UnitManaMax("player") + itemManaDelta + (15 * itemIntDelta);
		local replenishmp5 = 0.0125 * currentMana; -- 0.25% every sec = 1.25% every 5 sec
		manaRegenNormal = manaRegenNormal + replenishmp5;
		manaRegenCasting = manaRegenCasting + replenishmp5;

		local newMana = UnitManaMax("player") + itemManaDelta + (15 * itemIntDelta) + calcMana + 15 * calcInt;
		local replenishmp5New = 0.0125 * newMana; -- 0.25% every sec = 1.25% every 5 sec
		manaRegenNormalNew = manaRegenNormalNew + replenishmp5New;
		manaRegenCastingNew = manaRegenCastingNew + replenishmp5New;
	end

	if (_G["HealPointsOptionsConfigDivinePlea"]:GetChecked() == 1) then -- add divine plea
		local currentMana = UnitManaMax("player") + itemManaDelta + (15 * itemIntDelta);
		local replenishmp5 = 0.0208333 * currentMana; -- 25% every minute = 2.083% every 5 sec
		manaRegenNormal = manaRegenNormal + replenishmp5;
		manaRegenCasting = manaRegenCasting + replenishmp5;

		local newMana = UnitManaMax("player") + itemManaDelta + (15 * itemIntDelta) + calcMana + 15 * calcInt;
		local replenishmp5New = 0.0208333 * newMana; -- 25% every minute = 2.083% every 5 sec
		manaRegenNormalNew = manaRegenNormalNew + replenishmp5New;
		manaRegenCastingNew = manaRegenCastingNew + replenishmp5New;
	end

	return manaRegenNormal, manaRegenCasting, manaRegenNormalNew, manaRegenCastingNew, percentRegen;
end

local function getCurrentAndNewMaxMana_depricated(itemManaDelta, itemIntDelta)
	local currentMana = UnitManaMax("player") + itemManaDelta + (15 * itemIntDelta);

	local intDelta = _G["HealPointsVariables1InputBox"]:GetNumber() * (1 + BonusPercentInt);
	local newMana = currentMana + (_G["HealPointsVariables3InputBox"]:GetNumber() + 15 * intDelta);
	return currentMana, newMana;
end

local function getCurrentAndNewHealing_depricated(itemHealDelta, itemIntDelta, itemSpiDelta, itemAgiDelta)
	local intBonus = 0;
	local spiBonus = 0;
	local agiBonus = 0;
  
	local _, className = UnitClass("player");
	if (className == "PALADIN") then
		intBonus = 0.04 * HealPointsTalents:getTalentRank(HealPointsTalents.PALADIN.HOLYGU); -- 4/8/12/16/20% of intellect
	elseif (className == "PRIEST") then
		spiBonus = 0.05 * HealPointsTalents:getTalentRank(HealPointsTalents.PRIEST.SPIGUI); -- 5/10/15/20/25% of spirit
	elseif (className == "DRUID") then
		intBonus = 0.04 * HealPointsTalents:getTalentRank(HealPointsTalents.DRUID.LUNGUI); -- 4/8/12% of intellect
		agiBonus = 0.35 * HealPointsTalents:getTalentRank(HealPointsTalents.DRUID.NURINS); -- 35/70% of agility
		if (HealPointsUtil:isPlayerBuffUp(HealPointsLoc.BUFF_TREELI)) then
			spiBonus = 0.05 * HealPointsTalents:getTalentRank(HealPointsTalents.DRUID.IMPTOL); -- 5/10% of spirit while in Tree Form
		end 
	elseif (className == "SHAMAN") then
		intBonus = 0.05 * HealPointsTalents:getTalentRank(HealPointsTalents.SHAMAN.NATBLE); -- 5/10/15% of intellect
	end
	intBonus = intBonus; --+ 0.01 * HealPointsBS:GetBonus('HEALFROMINT');

	local healingDelta = intBonus * itemIntDelta + spiBonus * itemSpiDelta + agiBonus * itemAgiDelta;

	local healingDeltaNew = _G["HealPointsVariables7InputBox"]:GetNumber();
	itemIntDelta = itemIntDelta + _G["HealPointsVariables1InputBox"]:GetNumber() * (1 + BonusPercentInt); 
	itemSpiDelta = itemSpiDelta + _G["HealPointsVariables2InputBox"]:GetNumber() * (1 + BonusPercentSpi);
	healingDeltaNew = healingDeltaNew + intBonus * itemIntDelta + spiBonus * itemSpiDelta + agiBonus * itemAgiDelta;

	local currentHealing = GetSpellBonusHealing() + itemHealDelta;

	return currentHealing + healingDelta, currentHealing + healingDeltaNew;
end

local function getCurrentAndNewSpellCrit_depricated(itemIntDelta, itemCritRatingDelta)
	local spellCrit = 0;

	local _, className = UnitClass("player");
	if (className == "PALADIN" or className == "PRIEST") then
		spellCrit = GetSpellCritChance(2); -- Holy
	elseif (className == "DRUID" or className == "SHAMAN") then
		spellCrit = GetSpellCritChance(4); -- Nature
	end

	local critFromDeltaRating = StatLogic:GetEffectFromRating(itemCritRatingDelta, CR_CRIT_SPELL);
	local critFromDeltaInt = StatLogic:GetSpellCritFromInt(itemIntDelta);
	local currentSpellCrit = spellCrit + critFromDeltaRating + critFromDeltaInt;

	local critRatingDelta = itemCritRatingDelta + _G["HealPointsVariables8InputBox"]:GetNumber();
	local intDelta = itemIntDelta + _G["HealPointsVariables1InputBox"]:GetNumber() * (1 + BonusPercentInt);

	critFromDeltaRating = StatLogic:GetEffectFromRating(critRatingDelta, CR_CRIT_SPELL);
	critFromDeltaInt = StatLogic:GetSpellCritFromInt(intDelta);
	local newSpellCrit = spellCrit + critFromDeltaRating + critFromDeltaInt;

	return currentSpellCrit, newSpellCrit;
end

local function getCurrentAndNewSpellHaste_depricated(itemHasteRatingDelta)
	local spellHaste = GetCombatRatingBonus(CR_HASTE_SPELL);

	local hasteFromDelta = StatLogic:GetEffectFromRating(itemHasteRatingDelta, CR_HASTE_SPELL);
	local currentSpellHaste = spellHaste + hasteFromDelta;

	hasteFromDelta = StatLogic:GetEffectFromRating(itemHasteRatingDelta + _G["HealPointsVariables9InputBox"]:GetNumber(), CR_HASTE_SPELL);
	local newSpellHaste = spellHaste + hasteFromDelta;
  
	return currentSpellHaste, newSpellHaste;
end

local function displaySpellStats_depricated(spell) -- Show derived stats about specified spell
	if (BonusPercentInt == nil) then
		self:talentsChanged();
	end

	local _, manaRegenCasting, _, manaRegenCastingNew = getCurrentAndNewManaRegen(0, 0, 0, 0);
	local currentMana, newMana = getCurrentAndNewMaxMana(0, 0);
	local currentHealing, newHealing = getCurrentAndNewHealing(0, 0, 0, 0);
	local currentSpellCrit, newSpellCrit = getCurrentAndNewSpellCrit(0, 0);
	local currentSpellHaste, newSpellHaste = getCurrentAndNewSpellHaste(0);

	local oldHPSec = getHPSec(spell, currentHealing, currentSpellCrit, currentSpellHaste);
	local newHPSec = getHPSec(spell, newHealing, newSpellCrit, newSpellHaste);
	local oldHPMana = getHPMana(spell, currentHealing, currentSpellCrit);
	local newHPMana = getHPMana(spell, newHealing, newSpellCrit);
	local oldHPCast = getHPCast(spell, currentHealing, currentSpellCrit);
	local newHPCast = getHPCast(spell, newHealing, newSpellCrit);
	local oldHPTotalRegen, t1 = getHPTotalRegen(spell, currentHealing, currentSpellCrit, currentSpellHaste, manaRegenCasting, currentMana);
	local newHPTotalRegen, t2 = getHPTotalRegen(spell, newHealing, newSpellCrit, newSpellHaste, manaRegenCastingNew, newMana);
	local oldCrit = currentSpellCrit + HealPointsSpells:getSpellCritBonus(spell);
	local newCrit = newSpellCrit + HealPointsSpells:getSpellCritBonus(spell);
	local oldCastTime = HealPointsSpells:GetCastTime(spell, currentSpellHaste);
	local newCastTime = HealPointsSpells:GetCastTime(spell, newSpellHaste);

--[[
	-- Common stats
	HealPointsCalculatorUI:setSpellStat(1, "HP/s:", oldHPSec, newHPSec, "%d");
	HealPointsCalculatorUI:setSpellStat(2, "HP/mana:", oldHPMana, newHPMana, "%1.1f");
	HealPointsCalculatorUI:setSpellStat(3, "HP/cast:", oldHPCast, newHPCast, "%d");
	HealPointsCalculatorUI:setSpellStat(4, "HP/manabar:", oldHPTotalRegen, newHPTotalRegen, "%d");

	-- Spell specific stats
	if (spell['class'].type ~= 'hot') then
		HealPointsCalculatorUI:setSpellStat(5, "Spell crit(%):", oldCrit, newCrit, "%1.2f");
	else
		local oldHPTick = getHPTick(spell, currentHealing);
		local newHPTick = getHPTick(spell, newHealing);
		HealPointsCalculatorUI:setSpellStat(5, "HP/tick:", oldHPTick, newHPTick, "%d");
	end

	if (spell['class'].type ~= 'hot' and spell['class'].type ~= 'instant' and spell['class'].type ~= 'lifebloom' and
		spell.class.classID ~= HealPointsSpells.SPELL_HOLYNOVA and spell.class.classID ~= HealPointsSpells.SPELL_COH) then
		HealPointsCalculatorUI:setSpellStat(6, "Cast time:", oldCastTime, newCastTime, "%1.2f");
	elseif (spell['class'].type == 'lifebloom') then
		local oldHPTick = getHPTick(spell, currentHealing);
		local newHPTick = getHPTick(spell, newHealing);
		HealPointsCalculatorUI:setSpellStat(6, "HP/tick:", oldHPTick, newHPTick, "%d");
	else
		HealPointsCalculatorUI:setSpellStat(6, nil);
	end

	if (spell['class'].type == 'regrowth') then
		local oldHPTick = getHPTick(spell, currentHealing);
		local newHPTick = getHPTick(spell, newHealing);
		HealPointsCalculatorUI:setSpellStat(7, "HP/tick:", oldHPTick, newHPTick, "%d");
	else
		HealPointsCalculatorUI:setSpellStat(7, nil);
	end

	local healFactor1, healFactor2 = HealPointsSpells:getHealingFactor(spell);
	local spellBonus = HealPointsSpells:getHealingPercentBonus(spell);
	healFactor1 = healFactor1 * spellBonus;
	if (healFactor2 ~= nil) then
		healFactor2 = healFactor2 * spellBonus;
	end
	if (spell['class'].type == 'aoe') then
		healFactor1 = healFactor1 * math.min(5, HealPoints.db.char.hot['numtargets']);
	end
	HealPointsCalculatorUI:setHealFactor(spell, healFactor1, healFactor2);

	HealPointsCalculatorUI:setTimeToOOM(t1, t2);
--]]
end
